@@ -12,67 +12,15 @@ from werkzeug.utils import secure_filename
 from flask_executor.futures import Future
 
 # lib imports
-from .helpers import list_replace, calc_hash, get_logger, DEFAULT_TIMEOUT
+from .helpers import list_replace, gen_key, get_logger, DEFAULT_TIMEOUT
 
 logger = get_logger()
 
 
-def run_command(cmd: List[str], timeout: int, key: str) -> Dict:
+class RunnerParser:
     """
-    This function is called by the executor to run given command
-    using a subprocess asynchronously.
-
-    :param cmd: List[str]
-        command to run split as a list
-    :param key: str
-        future_key of particular Future instance
-    :param timeout: int
-        maximum timeout in seconds (default = 3600)
-
-    :rtype: Dict
-
-    :returns:
-        A Concurrent.Future object where future.result() is the report
-    """
-    start_time: float = time.time()
-    proc = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE,)
-    try:
-        outs, errs = proc.communicate(timeout=int(timeout))
-        stdout = outs.decode("utf-8")
-        stderr = errs.decode("utf-8")
-        returncode = proc.returncode
-        logger.info(f"Job: '{key}' --> finished with returncode: '{returncode}'.")
-
-    except subprocess.TimeoutExpired:
-        proc.kill()
-        stdout, _ = [s.decode("utf-8") for s in proc.communicate()]
-        stderr = f"command timedout after {timeout} seconds."
-        returncode = proc.returncode
-        logger.error(f"Job: '{key}' --> failed. Reason: \"{stderr}\".")
-
-    except Exception as e:
-        proc.kill()
-        returncode = -1
-        stdout = None
-        stderr = str(e)
-        logger.error(f"Job: '{key}' --> failed. Reason: \"{stderr}\".")
-
-    end_time: float = time.time()
-    process_time = end_time - start_time
-    return dict(
-        key=key,
-        report=stdout,
-        error=stderr,
-        returncode=returncode,
-        start_time=start_time,
-        end_time=end_time,
-        process_time=process_time,
-    )
-
-
-class RequestParser:
-    """
-    Utility class to parse incoming POST request data into meaningful arguments.
+    Utility class to parse incoming POST request
+    data into meaningful arguments, generate key and run command.
     Internal use Only.
     """
 
@@ -112,28 +60,30 @@ class RequestParser:
     def parse_req(self, request, base_command: str) -> (str, int, Dict, str):
         # default values if request is w/o any data
         # i.e. just run-script
+        tmpdir = None
+        # default values
         args: List[str] = []
         timeout: int = DEFAULT_TIMEOUT
-        tmpdir = None
         callback_context = {}
+        randomize_key = False
         if request.is_json:
             # request does not contain a file
             args = request.json.get("args", [])
             timeout: int = request.json.get("timeout", DEFAULT_TIMEOUT)
             callback_context = request.json.get("callback_context", {})
+            randomize_key = request.json.get("force_unique_key", False)
         elif request.files:
             # request contains file and form_data
             data = json.loads(request.form.get("request_json", "{}"))
             received_args = data.get("args", [])
             timeout: int = data.get("timeout", DEFAULT_TIMEOUT)
             callback_context = data.get("callback_context", {})
-            args, tmpdir = RequestParser.__parse_multipart_req(
-                received_args, request.files
-            )
+            randomize_key = data.get("force_unique_key", False)
+            args, tmpdir = self.__parse_multipart_req(received_args, request.files)
 
         cmd: List[str] = base_command.split(" ")
         cmd.extend(args)
-        key: str = calc_hash(cmd)
+        key: str = gen_key(cmd, randomize=randomize_key)
         if tmpdir:
             self.__tmpdirs.update({key: tmpdir})
 
@@ -158,3 +108,56 @@ class RequestParser:
             logger.debug(
                 f"Job: '{key}' --> Failed to clear Temporary directory: '{tmpdir}'."
             )
+
+    @staticmethod
+    def run_command(cmd: List[str], timeout: int, key: str) -> Dict:
+        """
+        This function is called by the executor to run given command
+        using a subprocess asynchronously.
+
+        :param cmd: List[str]
+            command to run split as a list
+        :param key: str
+            future_key of particular Future instance
+        :param timeout: int
+            maximum timeout in seconds (default = 3600)
+
+        :rtype: Dict
+
+        :returns:
+            A Concurrent.Future object where future.result() is the report
+        """
+        start_time: float = time.time()
+        proc = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE,)
+        try:
+            outs, errs = proc.communicate(timeout=int(timeout))
+            stdout = outs.decode("utf-8")
+            stderr = errs.decode("utf-8")
+            returncode = proc.returncode
+            logger.info(f"Job: '{key}' --> finished with returncode: '{returncode}'.")
+
+        except subprocess.TimeoutExpired:
+            proc.kill()
+            stdout, _ = [s.decode("utf-8") for s in proc.communicate()]
+            stderr = f"command timedout after {timeout} seconds."
+            returncode = proc.returncode
+            logger.error(f"Job: '{key}' --> failed. Reason: \"{stderr}\".")
+
+        except Exception as e:
+            proc.kill()
+            returncode = -1
+            stdout = None
+            stderr = str(e)
+            logger.error(f"Job: '{key}' --> failed. Reason: \"{stderr}\".")
+
+        end_time: float = time.time()
+        process_time = end_time - start_time
+        return dict(
+            key=key,
+            report=stdout,
+            error=stderr,
+            returncode=returncode,
+            start_time=start_time,
+            end_time=end_time,
+            process_time=process_time,
+        )
